@@ -5,8 +5,9 @@ from itertools import product
 from warnings import warn
 
 import ixmp
+import numpy as np
 import pandas as pd
-from ixmp.utils import as_str_list, isscalar
+from ixmp.utils import as_str_list
 
 log = logging.getLogger(__name__)
 
@@ -274,7 +275,7 @@ class Scenario(ixmp.Scenario):
                         recurse(_k, _v, parent=_parent)
 
             level = k
-            children = [v] if isscalar(v) else v
+            children = [v] if np.isscalar(v) else v
             for child in children:
                 hierarchy.append([level, child, parent])
                 nodes.append(child)
@@ -494,7 +495,7 @@ class Scenario(ixmp.Scenario):
         lt = self.par("technical_lifetime", filters=filters).at[0, "value"]
 
         # Duration of periods
-        data = self.par("duration_period")
+        data = self.par("duration_period").sort_values(by="year")
         # Cumulative sum for periods including the vintage period
         data["age"] = data.where(data.year >= yv, 0)["value"].cumsum()
 
