@@ -485,8 +485,7 @@ def make_westeros(mp, emissions=False, solve=False, quiet=True):
             **common,
             commodity="light",
             level="useful",
-            # FIXME should use demand_per_year; requires adjustments elsewhere.
-            value=(100 * gdp_profile).round(),
+            value=(demand_per_year * gdp_profile).round(),
             unit="GWa",
         ),
     )
@@ -507,9 +506,8 @@ def make_westeros(mp, emissions=False, solve=False, quiet=True):
             make_df(name, **common, technology=tec, commodity=c, level=l, value=value),
         )
 
-    # FIXME the value for wind_ppl should be 0.36; requires adjusting other tests.
     name = "capacity_factor"
-    capacity_factor = dict(coal_ppl=1.0, wind_ppl=1.0, bulb=1.0)
+    capacity_factor = dict(coal_ppl=1.0, wind_ppl=0.36, bulb=1.0)
     for tec, value in capacity_factor.items():
         scen.add_par(name, make_df(name, **common, technology=tec, value=value))
 
@@ -523,7 +521,7 @@ def make_westeros(mp, emissions=False, solve=False, quiet=True):
     for tec in "coal_ppl", "wind_ppl":
         scen.add_par(name, make_df(name, **common, technology=tec, value=0.1))
 
-    historic_demand = 0.85 * demand_per_year
+    historic_demand = 0.5 * demand_per_year
     historic_generation = historic_demand / grid_efficiency
     coal_fraction = 0.6
 
