@@ -54,10 +54,10 @@ def test_reporter_from_scenario(message_test_mp):
     assert len(rep.graph["all"]) == 123
 
     # Quantities have short dimension names
-    assert "demand:n-c-l-y-h" in rep.graph
+    assert "demand:n-c-l-y-h" in rep
 
     # Aggregates are available
-    assert "demand:n-l-h" in rep.graph
+    assert "demand:n-l-h" in rep
 
     # Quantities contain expected data
     dims = dict(coords=["chicago new-york topeka".split()], dims=["n"])
@@ -69,11 +69,11 @@ def test_reporter_from_scenario(message_test_mp):
     assert_qty_equal(obs, demand, check_attrs=False)
 
     # ixmp.Reporter pre-populated with only model quantities and aggregates
-    assert len(rep_ix.graph) == 5223
+    assert len(rep_ix.graph) == 5224
 
     # message_ix.Reporter pre-populated with additional, derived quantities
     # This is the same value as in test_tutorials.py
-    assert len(rep.graph) == 12688
+    assert len(rep.graph) == 12689
 
     # Derived quantities have expected dimensions
     vom_key = rep.full_key("vom")
@@ -129,16 +129,16 @@ def test_reporter_from_westeros(test_mp):
     )
     assert all(obs["year"] == [700, 710, 720] * 3)
 
-    obs = obs["value"].values
+    obs = obs.data["value"].values
     exp = [
-        4832.177734,
-        8786.515625,
-        12666.666016,
-        5555.555664,
-        8333.333984,
-        10555.555664,
-        305.748138,
-        202.247391,
+        2842.4574905205504,
+        5007.754294173518,
+        6933.333333333334,
+        3055.5555555555557,
+        4555.555555555556,
+        5777.777777777778,
+        381.57832228986877,
+        212.45943170979092,
         0.0,
     ]
     assert len(obs) == len(exp)
